using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Web.UI;
using System.Web.UI.Design;
using System.Web.UI.Design.WebControls;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace RussellMason.Web.UI.Office2007.Design
{

	/// <summary>
	/// Basic designer for Ribbon Group.
	/// </summary>
	public class RibbonGroupDesigner : ControlDesigner
	{

		#region Fields

		private RibbonGroup _control; 

		#endregion Fields

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the RibbonGroupDesigner class.
		/// </summary>
		public RibbonGroupDesigner()
		{
		}

		#endregion Constructors

		#region Properties

		/// <summary>
		/// Gets whether the control can be sized at design-time.
		/// </summary>
		public override bool AllowResize
		{
			get
			{
				return true;
			}
		}

		#endregion Properties

		#region Methods

		/// <summary>
		/// Initializes the control.
		/// </summary>
		/// <param name="component">
		/// The component to initialize.
		/// </param>
		public override void Initialize(IComponent component)
		{
			base.Initialize(component);
			base.SetViewFlags(ViewFlags.TemplateEditing, true);

			_control = (RibbonGroup) component;
		} 

		/// <summary>
		/// Generates design time HTML.
		/// </summary>
		/// <param name="regions">
		/// Template regions.
		/// </param>
		/// <returns>
		/// The design time HTML.
		/// </returns>
		public override String GetDesignTimeHtml(DesignerRegionCollection regions)
		{
			_control.FinalizeRender();

			TableCell cell = _control.FindControl("PlaceHolder") as TableCell;

			if (cell != null)
			{
			  cell.Attributes[DesignerRegion.DesignerRegionAttributeName] = "0";
			}

			EditableDesignerRegion region = new EditableDesignerRegion(this, _control.ID + "_0", false);

			regions.Add(region);

			string html = base.GetDesignTimeHtml();

			return html;
		}

		/// <summary>
		/// Gets template content for editable regions.
		/// </summary>
		/// <param name="region">
		/// The region being edited.
		/// </param>
		/// <returns>
		/// The region content.
		/// </returns>
		public override string GetEditableDesignerRegionContent(EditableDesignerRegion region)
		{
			string content = string.Empty;
			IDesignerHost host = (IDesignerHost) Component.Site.GetService(typeof(IDesignerHost));

			if (host != null)
			{
				ITemplate template = null;

				if (region.Name == _control.ID + "_0")
				{
					template = _control.PlaceHolder;
				}

				if (template != null)
				{
					content = ControlPersister.PersistTemplate(template, host);
				}
			}

			return content;
		}

		/// <summary>
		/// Sets template content for editable regions.
		/// </summary>
		/// <param name="region">
		/// The region being edited.
		/// </param>
		/// <param name="content">
		/// The content of the region.
		/// </param>
		public override void SetEditableDesignerRegionContent(EditableDesignerRegion region, string content)
		{
			if (content != null)
			{
				IDesignerHost host = (IDesignerHost) Component.Site.GetService(typeof(IDesignerHost));

				if (host != null)
				{
					ITemplate template = ControlParser.ParseTemplate(host, content);

					if (template != null)
					{
						if (region.Name.EndsWith(_control.ID + "_0"))
						{
							_control.PlaceHolder = template;
						}
					}
				}
			}
		} 

		#endregion Methods

	}

}
