using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Xml;

namespace RussellMason.Web.UI.Office2007
{

	/// <summary>
	/// Base class for Ribbon based controls
	/// </summary>
	public class RibbonControl : SharedStateWebControl
	{

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the RibbonControl class.
		/// </summary>
		public RibbonControl()
		{
		} 

		#endregion Constructors

		#region Properties

		/// <summary>
		/// Gets or sets whether a client-side button object is created.
		/// </summary>
		[
		DefaultValue(true),
		Description("Specifies whether a client-side button object is created.")
		]
		public override bool GenerateClientMember
		{
			get
			{
				return true;
			}
			set
			{
				if (!value)
				{
					string message =
						"GenerateClientMember must be set to true for this control to function correctly.";

					throw new NotSupportedException(message);
				}

				// Always returns true so no need to set anything
			}
		} 

		#endregion Properties

		#region Methods

		/// <summary>
		/// Serializes the object to the specified writer.
		/// </summary>
		/// <param name="writer">
		/// The writer to write to.
		/// </param>
		public virtual void Serialize(XmlWriter writer)
		{
			writer.WriteStartElement("RibbonControl");

			SerializeContent(writer);

			writer.WriteEndElement();
		}

		/// <summary>
		/// Deserializes the object from the specified node.
		/// </summary>
		/// <param name="element">
		/// The element to get property values from.
		/// </param>
		public virtual void Deserialize(XmlElement element)
		{
			if (element.HasAttribute("Enabled"))
			{
				string enabled = element.Attributes["Enabled"].Value;
				this.Enabled = Convert.ToBoolean(enabled);
			}
		}

		#endregion Methods

		#region Implementation Methods

		/// <summary>
		/// Writes the object's details to the specified writer. The Serialize method writes a generic 
		/// element, so in derived classes override this method to simplify the writing of content. Call
		/// base then add additional attributes or elemnts.
		/// <para />
		/// In derived classes ensure you call base prior to adding your content to ensure the correct 
		/// element definition is output.
		/// </summary>
		/// <param name="writer">
		/// The writer to write to.
		/// </param>
		protected virtual void SerializeContent(XmlWriter writer)
		{
			writer.WriteAttributeString("Type", GetType().Name);
			writer.WriteAttributeString("ID", this.ID);
			writer.WriteAttributeString("UniqueID", this.UniqueID);
			writer.WriteAttributeString("Enabled", this.Enabled.ToString());
		}

		#endregion Implementation Methods

	}

}
